@@ -74,10 +74,10 @@ class Elasticsearchlib:
         :param total_retries: number of consecutive retries before dropping the connection and throwing an Exception
         """
         ssl_context = create_default_context(cafile=certifi.where())
-        _es = Elasticsearch(hosts=[{'host': host, 'port': port}],
-                            http_auth=('easier', 'easier-123.'),
-                            scheme="https",
-                            connection_class=RequestsHttpConnection,
+        _es = Elasticsearch(hosts=[{'host': host, 'port': int(port)}],
+                            http_auth=(user, password),
+                            #scheme="https",
+                            #connection_class=RequestsHttpConnection,
                             use_ssl=True,
                             #ssl_context=ssl_context,
                             verify_certs=False)
